# application.rb
# Copyright (C) 2008, Darryl L. Pierce <mcpierce@gmail.com>
#
# This program is free software: you can redistribute it and/or modify it under
# the terms of the GNU General Public License as published by the Free Software
# Foundation, either version 3 of the License, or (at your option) any later
# version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
# details.
#
# You should have received a copy of the GNU General Public License along with
# this program.  If not, see <http://www.gnu.org/licenses/>.
#

class ApplicationController < ActionController::Base
  layout "default"

  before_filter :load_user
  before_filter :load_counts

  around_filter :handle_exceptions

  helper :all # include all helpers, all the time

  attr_accessor :breadcrumbs

  def initialize
    @breadcrumbs = Array.new
  end

  # See ActionController::RequestForgeryProtection for details Uncomment the
  # :secret if you're not using the cookie session store
  protect_from_forgery # :secret => '9c89a76e3c2615afe424b5811fe319f7'

  # Returns whether the current user has authenticated.
  #
  # An authenticated user has their user id stored in the session with the key
  # :user_id.
  def authenticated
    if @user == nil
      session[:original_uri] = request.request_uri
      flash[:message] = 'Please login first.'
      redirect_to login_url
    end
  end

  def load_user
    @user = User.find_by_id(session[:user_id])

    @admin_projects = (@user != nil) && @user.privileges.admin_projects
  end

  def load_counts
    @project_count = Project.find(:all).size
    @epic_count = Epic.find(:all).size
    @product_count = Product.find(:all).size
    @user_story_count = UserStory.find(:all).size
    @sprint_count = Sprint.find(:all).size
    @user_count = User.find(:all).size
  end

  def add_breadcrumb(text, url=nil)
    @breadcrumbs << Breadcrumb.new(text, url)
  end

  def create_rss_entry(title, link, content, author=nil)
    Feed.new(:title   => title,
             :link    => link,
             :content => content,
             :author  => author ? author : @user)
  end

  # Redirects the user to the error page and displays
  # the provided message.
  def report_error(message, url=nil)
    if url
      flash[:message] = message
    else
      flash[:error] = message
    end

    respond_to do |format|
      format.html { redirect_to url ? url : error_path }
    end
  end

  private

  def handle_exceptions
    yield
  rescue Exception => error
    logger.error("EXCEPTION: #{error.message}")
    # puts error.backtrace
    erase_results
    @title = "An Error Has Occurred."
    flash[:error] = "The following error has occurred: #{error.message}"
    redirect_to error_path
  end
end
