# messages_controller.rb
# Copyright (C) 2009, Darryl L. Pierce <mcpierce@gmail.com>
#
# This program is free software: you can redistribute it and/or modify it under
# the terms of the GNU General Public License as published by the Free Software
# Foundation, either version 3 of the License, or (at your option) any later
# version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along with
# this program. If not, see <http://www.gnu.org/licenses/>.
#

# +MessageController+ enforces business rules on instances of +Message+.
class MessagesController < ApplicationController
  before_filter :authenticated, :except => [:index, :show]
  before_filter :load_message, :except => [:index]
  before_filter :get_landing_page, :except => [:index, :show]

  # GET /messages
  def index
    @author = User.find_by_id(params[:author])
    @messages = Message.for_author(@author).paginate(:page     => params[:page],
                                                     :per_page => 10)
  end

  # GET /messages/1
  def show

  end

  # GET /message/1/reply
  def reply
    @reply = Message.new
  end

  # POST /messages/1
  def post_reply
    Message.transaction do
      @reply = Message.new(params[:reply])
      @reply.posted = Time.current
      @reply.author = @user
      @message.replies << @reply

      respond_to do |format|
        if @message.save
          UserMailer.deliver_message_reply_notice(@reply) if @message.author.notifications.email_on_replies
          flash[:message] = "Reply posted."
          if @landing_page
            format.html {redirect_to @landing_page}
          else
            format.html {redirect_to message_path(@message)}
          end
        else
          @reply.valid?
          format.html {render :action => :reply}
        end
      end
    end
  end

  private

  def load_message
    @message = Message.find_by_id(params[:id])

    report_error "Invalid or missing message." unless @message
  end

  def get_landing_page
    @landing_page = params[:dest]
  end
end
