# application_helper.rb
# Copyright (C) 2008, Darryl L. Pierce <mcpierce@gmail.com>
#
# This program is free software: you can redistribute it and/or modify it under
# the terms of the GNU General Public License as published by the Free Software
# Foundation, either version 3 of the License, or (at your option) any later
# version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
# details.
#
# You should have received a copy of the GNU General Public License along with
# this program.  If not, see <http://www.gnu.org/licenses/>.
#

module ApplicationHelper
  # Returns the first sentence from the supplied text, up to the first period.
  # If no period is present, then the whole text is returned. If not text is
  # present, then a single space is returned.
  def get_first_sentence(text)
    if (text == nil) || text.empty?
      return " "
    end

    return text.slice(/^[^\.]*\.?/)

  end

  # Displays a link and image reporting the health of the sprint
  def show_sprint_health(sprint)
    @template.image_tag(
      sprint.healthy? ? "/images/icons/healthy.png" : "/images/icons/unhealthy.png",
      :alt => sprint.healthy? ? "Sprint is healthy" : "Sprint is not healthy")
  end

  # Displays a date or date and time.
  def show_date(datetime, include_time = false)
    if include_time
      datetime.strftime("%m/%d/%Y %I:%M:%S %P")
    else
    datetime.strftime("%m/%d/%Y")
    end
  end

  # Creates a link to a backlog item.
  def link_to_backlog_item(backlog_item, options = {})
    @template.link_to(options[:text] ? options[:text] : backlog_item.title,
      :controller => :backlog,
      :action     => (options[:action] ? options[:action] : :view),
      :id         => backlog_item.id)
  end

  # Shows the hours for a given object as estimated, actual and remaining.
  def show_hours_as_ear(estimated)
    format("%0.1f/%0.1f/%0.1f",estimated.estimated_hours, estimated.actual_hours, estimated.remaining_hours)
  end
end
