# backlog_item_vote.rb
# Copyright (C) 2009, Darryl L. Pierce <mcpierce@gmail.com>
#
# This program is free software: you can redistribute it and/or modify it under
# the terms of the GNU General Public License as published by the Free Software
# Foundation, either version 3 of the License, or (at your option) any later
# version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
# details.
#
# You should have received a copy of the GNU General Public License along with
# this program.  If not, see <http://www.gnu.org/licenses/>.
#

# A +BacklogItemVote+ represents a single user's vote for or against a backlog item
# on a sprint backlog.
class BacklogItemVote < ActiveRecord::Base
  validates_presence_of(:user_id)
  validates_presence_of(:backlog_item_id)
  validates_presence_of(:vote, :message => "A ballot must be cast.")
  validates_numericality_of(:vote, :message => "A vote must be -1, 0 or 1.",
                            :only_integer => true,
                            :greater_than_or_equal_to => -1,
                            :less_than_or_equal_to => 1)

  belongs_to :user
  belongs_to :backlog_item

  named_scope :for_sprint, lambda {|sprint_id| {:conditions => ["backlog_item_id in (select id from backlog_items where sprint_id = ?)", sprint_id]}}
  named_scope :for_user, lambda {|user_id| {:conditions => ["user_id = ?", user_id]}}

  ABSTAIN = 0
  ACK = 1
  NAK = -1

  VOTES = {"Abstain" => ABSTAIN, "Accept" => ACK, "Reject" => NAK}
  VOTE_TEXT = {ABSTAIN => "Abstrained", ACK => "Accepted", NAK => "Rejected"}

  def validate
    errors.add("estimated_hours", "An accepted item must have an hours estimate.") if (vote == ACK) && (estimated_hours <= 0)
  end
end
