# message.rb
# Copyright (C) 2009, Darryl L. Pierce <mcpierce@gmail.com>
#
# This program is free software: you can redistribute it and/or modify it under
# the terms of the GNU General Public License as published by the Free Software
# Foundation, either version 3 of the License, or (at your option) any later
# version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
# details.
#
# You should have received a copy of the GNU General Public License along with
# this program.  If not, see <http://www.gnu.org/licenses/>.
#

# A +Message+ represents a single text body written by a user.
class Message < ActiveRecord::Base
  validates_presence_of(:author_id,
                        :message => 'An author is required.')
  validates_presence_of(:body,
                        :message => 'A message body is required.')
  validates_length_of(:body,
                      :within => 5..1000,
                      :too_long => 'Maximum message length is 1000 characters.',
                      :too_short => 'Please enter at least 5 characters.')
  validates_presence_of(:posted,
                        :message => 'A posting date is required.')

  belongs_to :author, :class_name => 'User', :foreign_key => :author_id

  acts_as_tree :foreign_key => :reference_id, :order => 'posted'
  has_many :replies, :class_name => 'Message', :foreign_key => :reference_id, :dependent => :delete_all
  belongs_to :reference, :class_name => 'Message', :foreign_key => :reference_id

  named_scope :default, :order => "created_at ASC"
  named_scope :blocker_messages, lambda {|backlog_item| {:conditions => ['id in (select message_id from backlog_items_messages where backlog_item_id = ?)', backlog_item.id]}}
  named_scope :for_author, lambda {|author| {:conditions => author ? ['author_id = ?', author.id] : ""}}

  def can_edit?(user)
    true
  end

  def can_delete?(user)
    true
  end
end
