# project_role.rb
# Copyright (C) 2008, Darryl L. Pierce <mcpierce@gmail.com>
#
# This program is free software: you can redistribute it and/or modify it under
# the terms of the GNU General Public License as published by the Free Software
# Foundation, either version 3 of the License, or (at your option) any later
# version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
# details.
#
# You should have received a copy of the GNU General Public License along with
# this program.  If not, see <http://www.gnu.org/licenses/>.
#

# A +ProductRole+ associates a +User+ with a +Role+ for a +Product+. It defines
# what privileges a user has regarding a +Product+.
#
class ProductRole < ActiveRecord::Base
  validates_presence_of :product_id,
    :message => 'A product must be specified.'

  validates_presence_of :user_id,
    :message => 'A user must be specified.'

  validates_presence_of :role_id,
    :message => 'A role must be specified.'

  belongs_to :product
  belongs_to :user
  belongs_to :role

  named_scope :for_project, lambda {|project_id| {:conditions => ['product_id in (select id from products where project_id = ?)', project_id]}}
  named_scope :for_product, lambda {|product_id| {:conditions => ['product_id = ?', product_id]}}
  named_scope :approved, {:conditions => 'is_approved = true and pending = false'}
  named_scope :for_user, lambda {|user_id| {:conditions => ['user_id = ?', user_id]}}

  # Sets the status for a pending role.
  def approved=(status)
    self.pending = false
    self.is_approved = status
  end

  # Returns the approval status.
  def approved
    is_approved
  end

  # gets the status for a

  # Returns whether the role is active.
  def active?
    !self.pending && self.approved
  end

  # Returns whether the user can delete this role.
  def can_delete?(user)
    (user != nil) && (user.id == product.owner_id)
  end
end
