# user_verification.rb
# Copyright (C) 2008, Darryl L. Pierce <mcpierce@gmail.com>
#
# This program is free software: you can redistribute it and/or modify it under
# the terms of the GNU General Public License as published by the Free Software
# Foundation, either version 3 of the License, or (at your option) any later
# version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
# details.
#
# You should have received a copy of the GNU General Public License along with
# this program.  If not, see <http://www.gnu.org/licenses/>.
#

# A +UserVerification+ object only exists when a user account needs to be
# verified.
#
# A verification contains a +token+ which must be received from the user in
# order to complete the validation. The token is 16 bytes long and consists only
# of alphanumeric characters.
#
class UserVerification < ActiveRecord::Base
  TOKEN_CHARACTERS = ('a'..'z').to_a + ('A'..'Z').to_a + ('0'..'9').to_a
  TOKEN_SIZE       = 16
  TOKEN_PATTERN    = "^[[:alnum:]]{#{TOKEN_SIZE}}$"

  validates_presence_of :user_id

  validates_presence_of :token
  validates_format_of :token,
    :with => /#{TOKEN_PATTERN}/

  validates_presence_of :sent

  belongs_to :user

  # Generates a verification token.
  def self.create_token
    (0...TOKEN_SIZE).collect { TOKEN_CHARACTERS[Kernel.rand(TOKEN_CHARACTERS.length)] }.join
  end

  # Returns whether the verification attempt has expired.
  def expired?
    attempts >= 3
  end
end
