# routers.rb
# Copyright (C) 2008, Darryl L. Pierce <mcpierce@gmail.com>
#
# This program is free software: you can redistribute it and/or modify it under
# the terms of the GNU General Public License as published by the Free Software
# Foundation, either version 3 of the License, or (at your option) any later
# version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
# details.
#
# You should have received a copy of the GNU General Public License along with
# this program.  If not, see <http://www.gnu.org/licenses/>.
#

ActionController::Routing::Routes.draw do |map|
  map.admin "/admin", :controller => 'admin', :action => 'index'

  map.resource :admin do |admin|
    admin.resource :server, :controller => 'ServerSettings'
  end

  map.resources :projects, :member =>
    {
    :approve => :put,
    :reject  => :put
  }

  map.resources :epics, :member =>
    {
    :close   => :put,
    :reopen  => :put,
    :comment => :post
  }

  map.resources :stories, :member =>
    {
    :comment      => :post,
  }

  map.resources :products, :member => {:rss => :get} do |product|
    product.resources :roles
  end

  map.resources :sprints, :member =>
    {
    :planning   => :put,
    :start      => :put,
    :complete   => :put,
    :cancel     => :put,
    :plan       => :get,
    :populate   => :post,
    :members    => :get,
    :vote       => :get,
    :cast_votes => :post
  }

  map.resources :items, :member =>
    {
    :accept         => :get,
    :blocked        => :get,
    :update_blocked => :post,
    :drop           => :get,
    :complete       => :get,
    :reopen         => :get,
    :estimate       => :post,
    :defer          => :put
  }

  map.resources :users, :member =>
    {
    :backlog         => :get,
    :roles           => :get,
    :notifications   => :post,
    :password        => :get,
    :change_password => :post
  }

  map.resources :tasks

  map.resources :messages, :member =>
    {
    :reply      => :get,
    :post_reply => :post
  }

  # You can have the root of your site routed with map.root -- just remember to
  # delete public/index.html.
  map.root :controller => 'home'

  # Account routes
  map.login "/login", :controller => 'home', :action => 'login'
  map.logout "/logout", :controller => 'home', :action => 'logout'
  map.register "/register", :controller => 'users', :action => 'new'
  map.dashboard "dashboard", :controller => 'home', :action => 'dashboard'

  # Error handling
  map.error "/error", :controller => 'home', :action => 'error'

  map.email_verification "verify/:id/:token",
    :controller => 'users',
    :action     => 'verify',
    :defaults   => { :token => nil }

  # Install the default routes as the lowest priority.
  map.connect ':controller/:action/:id'
  map.connect ':controller/:action/:id.:format'
end
