# 016_create_config_properties.rb
# Copyright (C) 2008, Darryl L. Pierce <mcpierce@gmail.com>
#
# This program is free software: you can redistribute it and/or modify it under
# the terms of the GNU General Public License as published by the Free Software
# Foundation, either version 3 of the License, or (at your option) any later
# version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
# details.
#
# You should have received a copy of the GNU General Public License along with
# this program.  If not, see <http://www.gnu.org/licenses/>.
#

class CreateConfigProperties < ActiveRecord::Migration
  def self.up
    create_table :config_properties do |t|
      t.string  :name,  :null => false, :unique => true,  :limit => 128
      t.text    :value, :null => true,  :unique => false

      t.timestamps
    end

    ConfigProperty.store('text.home_page',
                         "h1. Welcome To ProjXP!\r\n\n" +
                         "ProjXP is an agile project management system. Its goal is to enable developers in multiple locations to use agile development practices effectively.\r\n\n" +

                         "h2. What Is Agile Development?\r\n\n" +
                         "Agile development is \"defined\":http://en.wikipedia.org/wiki/Agile_software_development as:\r\n\n" +
                         "bq. group of software development methodologies based on iterative development, where requirements and solutions evolve through collaboration between self-organizing cross-functional teams.\r\n\n" +
                         "Agile development enables teams to more quickly and effectively perform development  by requiring that features be prioritized, and development to be done in short, achievable cycles, called sprints.\r\n\n" +
                         "*ProjXP* enables teams to use this methodology by providing a way for project and product owners to prioritize the list of features needed for an application. " +
                         "Developers and product owners then work together to define sprints and include those features. " +
                         "Project owners can then monitor development progress without distracting the development team.\r\n\n" +

                         "h2. What Are Projects and Products?\r\n\n" +
                         "The term _product_ refers to a group whose goal is to provide a programming artifact, such as a an application, or a website, documentation or even a shared library or web service.\r\n\n" +
                         "The term _project_ is used to group together one or more directly related _products_.\r\n\n" +
                         "For example, a project may be composed of several product teams:\r\n\n" +
                         "* *the web developers*, who provide the user interface for a web application,\r\n" +
                         "* *the desktop developers*, who create a desktop application providing the same features,\r\n" +
                         "* *the web services team*, who create a series of shared services that the web and application teams access.\r\n\n" +
                         "h2. Epic Stories And User Stories\r\n\n" +
                         "An _epic story_ is an overarching feature, one that is provided by more then one product. In the above example, one such epic could include SSO[1].\r\n\n" +
                         "A _user story_ is a feature provided by a single product. User stories can also be related to epic stories if they fulfill that epic's requirements. So, for example, the desktop app could provide an interface for SSO, the web application an HTML template, and the web services group a service to perform such authentication.\r\n\n" +
                         "h2. How Does ProjXP Help?\r\n\n" +
                         "With *ProjXP*, project owners can focus on maintaining the list of epic stories their project wants to achieve. They can focus on coordinating at a higher level what needs to be done to make the project successful.\r\n\n" +
                         "Product owners can draw from the project's epic stories, as well as define their own features that need to be accomplished.\r\n\n" +
                         "Sprint teams can streamline their development efforts by focusing on the next task to be performed, and provide feedback to the team leader and product owner by recording how much work was done. This allows for tracking a teams overall velocity[2] during a sprint. Developers can also have *ProjXP* automatically send a daily email to the team's mailing listing those items he completed the day before, the items that are open, and also what items are current blockers. This helps to keep the rest of the team informed about what everybody else is working on, enabling collaboration.\r\n\n" +

                         "h2. Getting Started\r\n" +
                         "# Create a project.\r\n" +
                         "# Create a product.\r\n" +
                         "# Enter a set of user stories.\r\n" +
                         "# Add members to the product team.\r\n" +
                         "# Define a new sprint, and create backlog.\r\n" +
                         "# Start the sprint, and get busy!\r\n\n" +

                         "fn1. Shared sign on.\r\n\n" +
                         "fn2. See \"here\":http://www.netobjectives.com/blogs/agile-development-velocity-is-the-measure-you-want for more information on velocity.\r\n"
                           )
    ConfigProperty.store("image.default_project_logo", "/images/project.png")
    ConfigProperty.store("image.product_logo_path", "/images/products")
    ConfigProperty.store("image.default_user_avatar", "/images/users/avatar.png")
  end

  def self.down
    drop_table :config_properties
  end
end
