# avatar.rb
# Copyright (C) 2008, Darryl L. Pierce <mcpierce@gmail.com>
#
# This program is free software: you can redistribute it and/or modify it under
# the terms of the GNU General Public License as published by the Free Software
# Foundation, either version 3 of the License, or (at your option) any later
# version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
# details.
#
# You should have received a copy of the GNU General Public License along with
# this program.  If not, see <http://www.gnu.org/licenses/>.
#

# Generates a URL for Gravatar-hosted images.
def gravatar_url(email, size="80", rating=nil, default=nil)
  # The supported ratings from gravatar
  allowed_ratings = ['g', 'pg', 'r', 'x']

  # query will be our extra param string
  query = "s=" + size + "&"
  # if we have a rating ...
  if rating != nil
    # ... and it is allowed
    if allowed_ratings.index(rating) != nil
      query += "r=" + rating + "&"
    else
      # if it is not allowed, raise an exception
      raise "No such gravatar rating: '" + rating + "'"
    end
  end
  # if we have a default then use it
  if default != nil
    query += "d=" + URI.parse(URI.encode(default)).to_s() + "&"
  end
  # put it all together in an HTTP object
  url = URI::HTTP.build({
                          :host => 'www.gravatar.com',
                          :path => '/avatar/' + Digest::MD5.hexdigest(email),
                          :query => query[0, query.size()-1]
                        })
  # and return the built string
  return url.to_s()
end
