# home_controller_test.rb
# Copyright (C) 2008, Darryl L. Pierce <mcpierce@gmail.com>
#
# This program is free software: you can redistribute it and/or modify it under
# the terms of the GNU General Public License as published by the Free Software
# Foundation, either version 3 of the License, or (at your option) any later
# version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
# details.
#
# You should have received a copy of the GNU General Public License along with
# this program.  If not, see <http://www.gnu.org/licenses/>.
#

require File.dirname(__FILE__) + '/../test_helper'

class HomeControllerTest < ActionController::TestCase
  fixtures :users

  def setup
    @controller = HomeController.new
    @authenticated_user = users(:mcpierce)
    @backlog = BacklogItem.find_all_by_state_and_owner_id(BacklogItem::STATE_ASSIGNED,@authenticated_user.id)

    # setup for testing mail
    ActionMailer::Base.delivery_method = :test
    ActionMailer::Base.perform_deliveries = true
    ActionMailer::Base.deliveries = []
  end

  # Ensures that anonymous users are sent to the login page when they try to
  # view the dashboard.
  #
  def test_dashboard_for_anonymous_user
    get :dashboard

    assert_redirected_to :controller => :home, :action => :login
    assert session[:original_uri], 'URL was not stored.'
  end

  # Ensures that authenticated users are shown their dashboard.
  #
  def test_dashboard_for_authenticated_user
    get :dashboard, nil, {:user_id => @authenticated_user.id}

    assert_response :success
    assert assigns['backlog'], 'Did not retrieve the user backlog'
    assert_equal @backlog.size, assigns['backlog'].size, 'Did not load the right set of tasks'
  end

  # Ensures that a failed login redirects back to the login action.
  #
  def test_login_failure
    get :dashboard

    assert_redirected_to :action => :login

    post :login, {:email    => 'mcpierce@gmail.com',
      :password => 'klefar' }

    assert_redirected_to :action => :login
    assert session[:original_uri], 'Lost the redirect URL'
  end

  # Ensures that a user who logs in is sent to their dashboard.
  #
  def test_login_failure
    post :login, {:email    => 'mcpierce@gmail.com',
      :password => 'farkle'}

    assert_redirected_to dashboard_url
  end

  # Ensures that the user's session is destroyed on logout.
  #
  def test_logout
    get :logout, nil, {:user_id => @authenticated_user.id}

    assert_redirected_to :action => :login
    assert_nil session[:user_id], 'User id was not deleted.'
  end

  # Ensures that the main page doesn't require the user be logged.
  #
  def test_index
    get :index

    assert_response :success
  end

end
