# report_controller_test.rb
# Copyright (C) 2008, Darryl L. Pierce <mcpierce@gmail.com>
#
# This program is free software: you can redistribute it and/or modify it under
# the terms of the GNU General Public License as published by the Free Software
# Foundation, either version 3 of the License, or (at your option) any later
# version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
# details.
#
# You should have received a copy of the GNU General Public License along with
# this program.  If not, see <http://www.gnu.org/licenses/>.
#

require File.dirname(__FILE__) + '/../test_helper'

class ReportControllerTest < ActionController::TestCase
  fixtures :sprints
  fixtures :users

  def setup
    @planned_sprint = sprints(:planned_sprint)
    @sprint = sprints(:active_sprint)
    @user = users(:mcpierce)
  end

  # Ensures that an error occurs when no sprint id was provided.
  #
  def test_burndown_graphic_without_sprint_id
    get :burndown_graphics

    assert_redirected_to error_url
  end

  # Ensures that trying to print a burndown report for a planned sprint fails.
  #
  def test_burndown_graphic_fails_for_planned_sprint
    get :burndown_graphic, {:id => @planned_sprint.id}

    assert_redirected_to sprint_path(@planned_sprint)
  end

  # Ensures that a burndown chart works as expected.
  #
  def test_burndown_graphic
    get :burndown_graphic, {:id => @sprint.id, :size => 0}

    assert_response :success
    assert assigns['data'], "Didn't generate the data needed for a report."
  end

  # Ensures that an effort report requires a user id.
  #
  def test_effort_without_user_id
    get :effort

    assert_redirected_to error_url
  end

  # Ensures that the user id must be valid for an effort report.
  #
  def test_effort_with_invalid_user_id
    get :effort, {:id => 9999}

    assert_redirected_to error_url
  end

  # Ensures that a well formed request works.
  #
  def test_effort
    get :effort, {:id => @user.id}

    assert_response :success
    assert assigns['tasks'], 'Failed to load the set of tasks for the given user.'
  end
end
