# server_settings_controller.rb
# Copyright (C) 2009, Darryl L. Pierce <mcpierce@gmail.com>
#
# This program is free software: you can redistribute it and/or modify it under
# the terms of the GNU General Public License as published by the Free Software
# Foundation, either version 3 of the License, or (at your option) any later
# version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
# details.
#
# You should have received a copy of the GNU General Public License along with
# this program.  If not, see <http://www.gnu.org/licenses/>.
#

require File.dirname(__FILE__) + '/../test_helper'

class ServerSettingsControllerTest < ActionController::TestCase
  fixtures :user_privileges
  fixtures :users

  def setup
    @admin = users(:admin)
    raise "Admin user must have admin privileges" unless @admin.privileges.admin_site

    @system_name = config_properties(:system_name).value
  end

  # Ensures the right values are loaded when editing the system settings.
  def test_edit
    get :edit, {}, {:user_id => @admin.id}

    assert_response :success
    assert_equal assigns['system_name'], @system_name, "Failed to load the system name."
  end

  # Ensures that saving values works as expected.
  def test_update
    put :update, {:system_name => "new system name"}, {:user_id => @admin.id}

    assert_redirected_to admin_server_path
    assert_equal ConfigProperty.fetch("system.name"), "new system name", "Failed to store the system name"
  end
end
