# backlog_item_vote_test.rb
# Copyright (C) 2008, Darryl L. Pierce <mcpierce@gmail.com>
#
# This program is free software: you can redistribute it and/or modify it under
# the terms of the GNU General Public License as published by the Free Software
# Foundation, either version 3 of the License, or (at your option) any later
# version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
# details.
#
# You should have received a copy of the GNU General Public License along with
# this program.  If not, see <http://www.gnu.org/licenses/>.
#

require File.dirname(__FILE__) + '/../test_helper'

class BacklogItemVoteTest < ActiveSupport::TestCase
  def setup
    @new_vote = BacklogItemVote.new(:user_id         => users(:mcpierce),
                                    :backlog_item_id => backlog_items(:planned_sprint_backlog_item),
                                    :vote            => BacklogItemVote::ACK,
                                    :estimated_hours => 5.0)
  end

  # Ensures that a vote requires a user.
  def test_valid_fails_without_user
    @new_vote.user_id = nil
    fail "A user is required." if @new_vote.valid?
  end

  # Ensures that a vote requires a backlog item.
  def test_valid_fails_without_backlog_item
    @new_vote.backlog_item_id = nil
    fail "A backlog item is required." if @new_vote.valid?
  end

  # Ensures that a vote requires a vote value.
  def test_valid_fails_without_vote
    @new_vote.vote = nil
    fail "A vote is required." if @new_vote.valid?
  end

  # Ensures that a vote must be numeric.
  def test_valid_fails_with_nonnumeric_vote
    @new_vote.vote = 'a'
    fail "A vote must be numeric!" if @new_vote.valid?
  end

  # Ensures that a vote can only be in the set of -1, 0 and 1.
  def test_valid_fails_with_invalid_votes
    [-1, 0, 1].each {|vote| @new_vote.vote = vote; fail "#{vote} must be a valid vote!" unless @new_vote.valid?}
    [-3, -2, 2, 3, 1.1].each {|vote| @new_vote.vote = vote; fails "#{vote} must be considered invalid!" if @new_vote.valid?}
  end

  # Ensures that, if an ACK is received, it must have a positive estimated value.
  def test_valid_fails_without_estimate_on_ack
    @new_vote.vote = BacklogItemVote::ACK
    @new_vote.estimated_hours = 0
    fail "An accept must have an estimate." if @new_vote.valid?
  end

  # Ensures that validation works as expected.
  def test_valid
    fail "There is a general validation error." unless @new_vote.valid?
  end
end
