# feeds_test.rb
# Copyright (C) 2009, Darryl L. Pierce <mcpierce@gmail.com>
#
# This program is free software: you can redistribute it and/or modify it under
# the terms of the GNU General Public License as published by the Free Software
# Foundation, either version 3 of the License, or (at your option) any later
# version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
# details.
#
# You should have received a copy of the GNU General Public License along with
# this program.  If not, see <http://www.gnu.org/licenses/>.
#

require File.dirname(__FILE__) + '/../test_helper'

class FeedTest < ActiveSupport::TestCase
  def setup
    @new_feed = Feed.new(:title   => "Test title",
                         :link    => "http://localhost/",
                         :author  => users(:mcpierce),
                         :content => "Yo yo yo")
  end

  # Ensures a feed requires a title.
  def test_valid_fails_without_title
    @new_feed.title = nil
    flunk "A feed must have a title." if @new_feed.valid?
  end

  # Ensures that the title must have text.
  def test_valid_fails_for_empty_title
    @new_feed.title = ""
    flunk "A feed title must have text." if @new_feed.valid?
  end

  # Ensures that the feed must have a link.
  def test_valid_fails_without_link
    @new_feed.link = nil
    flunk "A feed needs a link." if @new_feed.valid?
  end

  # Ensures that the feed must have an author.
  def test_valid_fails_without_author
    @new_feed.author = nil
    flunk "A feed requires an author." if @new_feed.valid?
  end

  # Ensures that a feed has content.
  def test_valid_fails_without_content
    @new_feed.content = nil
    flunk "A feed must have content." if @new_feed.valid?
  end

  # Ensures that content cannot be empty.
  def test_valid_fails_with_empty_content
    @new_feed.content = ""
    flunk "A feed must have content." if @new_feed.valid?
  end

  # Ensures that a well-formed feed is allowed.
  def test_valid
    flunk "There is a general validation error." unless @new_feed.valid?
  end
end
