# message_test.rb
# Copyright (C) 2008, Darryl L. Pierce <mcpierce@gmail.com>
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

require File.dirname(__FILE__) + '/../test_helper'

class MessageTest < ActiveSupport::TestCase
  fixtures :messages
  fixtures :users

  def setup
    @author = users(:mcpierce)
    @message = Message.new(:author => @author, :body => 'This is a message body.', :posted => Date.today)
  end

  # Ensures an author is required.
  def test_valid_fails_without_author
    @message.author_id = nil

    fail "An author must be required." if @message.valid?
  end

  # Ensures that a message body is required.
  def test_valid_fails_without_body
    @message.body = nil

    fail "A message body must be required." if @message.valid?
  end

  # Ensures that a minimum message body is required.
  def test_valid_fails_with_too_short_body
    @message.body = '1234'

    fail "A message has to be at least 5 characters." if @message.valid?
  end

  # Ensures that a maximum message body is defined.
  def test_valid_fails_with_too_long_body
    @message.body = (1..1001).collect { "a" }.join("")

    fail "A message body can't be more than 1000 characters." if @message.valid?
  end

  # Ensures that a posting date is required.
  def test_valid_fails_without_posted_date
    @message.posted = nil

    fail "A message must have a posted date." if @message.valid?
  end

  # Ensures that a well-formed message is valid.
  def test_valid
    fail "A general validation error exists for messages." unless @message.valid?
  end
end
