# product_role_test.rb
# Copyright (C) 2008, Darryl L. Pierce <mcpierce@gmail.com>
#
# This program is free software: you can redistribute it and/or modify it under
# the terms of the GNU General Public License as published by the Free Software
# Foundation, either version 3 of the License, or (at your option) any later
# version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
# details.
#
# You should have received a copy of the GNU General Public License along with
# this program.  If not, see <http://www.gnu.org/licenses/>.
#

require File.dirname(__FILE__) + '/../test_helper'

class ProductRoleTest < ActiveSupport::TestCase
  fixtures :products
  fixtures :roles
  fixtures :users

  def setup
    @product = products(:projxp_web)
    @role    = roles(:developer)
    @user    = users(:mcpierce)

    @new_role = ProductRole.new(
      :product_id => @product.id,
      :role_id    => @role.id,
      :user_id    => @user.id)
  end

  # Ensures that a product role requires a product.
  def test_valid_fails_without_product
    @new_role.product = nil

    flunk "Product role must require a product." if @new_role.valid?
  end

  # Ensurs that a product role requires a user.
  def test_valid_fails_without_user
    @new_role.user = nil

    flunk "Product role must require a user." if @new_role.valid?
  end

  # Ensures that a product role requires a role.
  def test_valid_fails_wihout_role
    @new_role.role = nil

    flunk "Product role must require a role." if @new_role.valid?
  end

  # Ensures that a well-formed product role is valid.
  def test_valid
    assert @new_role.valid?, 'Validation test has problems.'
  end
end
