# Copyright (C) 2009, Darryl L. Pierce <mcpierce@gmail.com>
#
# This program is free software: you can redistribute it and/or modify it under
# the terms of the GNU General Public License as published by the Free Software
# Foundation, either version 3 of the License, or (at your option) any later
# version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
# details.
#
# You should have received a copy of the GNU General Public License along with
# this program.  If not, see <http://www.gnu.org/licenses/>.
#

require File.dirname(__FILE__) + '/../test_helper'

class SprintTeamTest < ActiveSupport::TestCase
  fixtures :sprint_members
  fixtures :sprints
  fixtures :users

  def setup
    @sprint    = sprints(:startable_sprint)
    @team_lead = @sprint.team_lead
    @member    = users(:mcpierce)

    @membership = SprintMember.new(:sprint => @sprint, :member => @member)
    @existing_membership = sprint_members(:mcpierce_active_sprint)
  end

  # Ensures that a membership requires a sprint reference.
  def test_sprint_is_required
    @membership.sprint = nil
    flunk "Membership requires a sprint." if @membership.valid?
  end

  # Ensures that a membership requires a user reference.
  def test_member_is_required
    @membership.member = nil
    flunk "Membership requires a member." if @membership.valid?
  end

  # Ensures that a well-formed membership is valid.
  def test_valid
    flunk "There is a general validation error." unless @membership.valid?
  end

  # Ensures that a user cannot have two memberships to the same sprint.
  def test_unique_memberships
    membership = SprintMember.new(:sprint => @existing_membership.sprint,
                                  :member => @existing_membership.member)
    flunk "There is a problem with uniqueness constraints." if membership.valid?
  end
end
