# user_story_test.rb
# Copyright (C) 2008, Darryl L. Pierce <mcpierce@gmail.com>
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

require File.dirname(__FILE__) + '/../test_helper'

class UserStoryTest < ActiveSupport::TestCase
  fixtures :user_stories

  def setup
    @new_story = UserStory.new(:product_id => 1,
                               :priority   => 1,
                               :title      => 'This is a new user story.')
    @story = user_stories(:create_user_story)
    @nonmember = users(:celliot)
    raise "Non-member cannot be on the product team!" if @story.product.is_member?(@nonmember)
    @member = ProductRole.for_product(@story.product).approved.first.user
    raise "No approved members were found!" unless @member
  end

  # Ensures that a product is required.
  #
  def test_valid_fails_without_product
    @new_story.product = nil

    flunk "A product must be required." if @new_story.valid?
  end

  # Ensures that a priority is required.
  #
  def test_valid_fails_without_priority
    @new_story.priority = nil

    flunk "A priority is required." if @new_story.valid?
  end

  # Ensures that a priorty must be a numerical value.
  #
  def test_valid_fails_with_nonnumeric_priority
    @new_story.priority = 'abc'

    flunk "Priority must be a numeric value." if @new_story.valid?
  end

  # Ensures that a priority must be a positive integer.
  #
  def test_valid_fails_with_negative_priority
    @new_story.priority = -1

    flunk "Priority must not be negative." if @new_story.valid?
  end

  # Ensures that the priority cannot be zero.
  #
  def test_valid_fails_with_zero_priority
    @new_story.priority = 0

    flunk "Priority must be greater than zero." if @new_story.valid?
  end

  # Ensures that a title must be supplied.
  #
  def test_valid_fails_without_title
    @new_story.title = ""

    flunk "A title must be supplied." if @new_story.valid?
  end

  # Ensures that only team members can comment on a user story.
  def test_can_comment_for_nonmember
    flunk "Non-members cannot comment on user stories." if @story.can_comment?(@nonmember)
  end

  # Ensures comments can be posted.
  def test_can_comment
    flunk "Members must be able to comment." unless @story.can_comment?(@member)
  end
end
