# user_verification_test.rb
# Copyright (C) 2008, Darryl L. Pierce <mcpierce@gmail.com>
#
# This program is free software: you can redistribute it and/or modify it under
# the terms of the GNU General Public License as published by the Free Software
# Foundation, either version 3 of the License, or (at your option) any later
# version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
# details.
#
# You should have received a copy of the GNU General Public License along with
# this program.  If not, see <http://www.gnu.org/licenses/>.
#

require File.dirname(__FILE__) + '/../test_helper'

class UserVerificationTest < ActiveSupport::TestCase

  def setup
    @verification = UserVerification.new(
      :user_id => 1,
      :token   => UserVerification.create_token,
      :sent    => Date.today)
  end

  # Ensures that a verification requires an associated user.
  def test_valid_fails_without_user_id
    @verification.user_id = nil

    flunk "A user must be specified." if @verification.valid?
  end

  # Ensures that a verification token is required.
  def test_valid_fails_without_token
    @verification.token = nil

    flunk "A token must be specified." if @verification.valid?
  end

  # Ensures that a verification token must be 16 alpha-numeric characters.
  def test_valid_fails_with_invalid_token
    @verification.token = "this is invalid!"

    flunk "Tokens must be 16 alpha-numeric characters only." if @verification.valid?
  end

  # Ensures that a sent date has to be set.
  def test_valid_fails_without_sent_date
    @verification.sent = nil

    flunk "Verification must have a sent date." if @verification.valid?
  end

  # Ensures taht a well-formed verification is considered valid.
  def test_valid
    flunk "There is a problem in validation." unless @verification.valid?
  end

  # Ensures that the token generator always creates a 16-character alphanumeric
  # token.
  def test_create_token
    (1..100).each do |num|
      token = UserVerification.create_token

      flunk "The token generator is broken." unless token =~ /#{UserVerification::TOKEN_PATTERN}/
    end
  end
end
